==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sr-CS/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Korisnik je otkazao zahtev za stavke na Web lokaciji',
    'a_user_requested' => 'Korisnik je zatražio stavke na Web lokaciji',
    'accessory_name' => 'Naziv dodatne opreme, pribora:',
    'additional_notes' => 'Dodatne napomene:',
    'admin_has_created' => 'Administrator je kreirao nalog za vas na na :web vebsajtu.',
    'asset' => 'Imovina:',
    'asset_name' => 'Naziv imovine:',
    'asset_requested' => 'Traženo sredstvo',
    'asset_tag' => 'Oznaka imovine:',
    'assigned_to' => 'Dodijeljena',
    'best_regards' => 'Srdačan pozdrav',
    'canceled' => 'Otkazano:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'click_to_confirm' => 'Kliknite na sljedeći link kako biste potvrdili svoj :web nalog:',
    'click_on_the_link_accessory' => 'Kliknite na link pri dnu da biste potvrdili da ste primili dodatnu opremu.',
    'click_on_the_link_asset' => 'Kliknite na link pri dnu da biste potvrdili da ste primili resurs, imovinu.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Trenutna QTY',
    'Days' => 'Dani',
    'days' => 'Dana',
    'expecting_checkin_date' => 'Expected Checkin Date:',
    'expires' => 'Ističe',
    'Expiring_Assets_Report' => 'Expiring Assets Report.',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report.',
    'hello' => 'Zdravo',
    'hi' => 'Zdravo',
    'i_have_read' => 'Pročitao sam i prihvatam uvete korištenja i primio sam ovu stavku.',
    'item' => 'Artikal:',
    'Item_Request_Canceled' => 'Zahtev za stavku je otkazan',
    'Item_Requested' => 'Zahtevana stavka',
    'link_to_update_password' => 'Kliknite na sljedeći link kako biste potvrdili svoj :web nalog:',
    'login_first_admin' => 'Login to your new Snipe-IT installation using the credentials below:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Izveštaj o niskim zalihama',
    'min_QTY' => 'Min Kol',
    'name' => 'Naziv',
    'new_item_checked' => 'Nova stavka je proverena pod vašim imenom, detalji su u nastavku.',
    'password' => 'Lozinka:',
    'password_reset' => 'Ponovno postavljanje lozinke',

    'read_the_terms' => 'Pročitajte uslove upotrebe u nastavku.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read
                         and agree to the terms of use, and have received the asset.',
    'requested' => 'Traženi:',
    'reset_link' => 'Link za resetovanje lozinke',
    'reset_password' => 'Kliknite ovde da biste poništili lozinku:',
    'serial' => 'Serial',
    'supplier' => 'Dobavljač',
    'tag' => 'Tag',
    'test_email' => 'Isprobajte e-poštu od Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'low_inventory_alert' => 'Postoji :count artikla ispod minimalne zalihe ili će uskoro biti nizak. |Postoje :count artikla koji su ispod minimalne zalihe ili će uskoro biti.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'Postoji :count licenci koja/e ističe u narednih treshold dana.|Postoje :count licencei koje ističu u narednih :treshold dana.',
    'to_reset' => 'Da biste resetovali svoju :web lozinku, ispunite ovaj obrazac:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Korisnik',
    'username' => 'Korisničko ime',
    'welcome' => 'Dobrodošli :name',
    'welcome_to' => 'Dobrodošli na :web!',
    'your_credentials' => 'Vaši Snipe-IT kredencijali',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sr-CS/mail.php <==
<?php

return [
    'a_user_canceled' => 'Korisnik je otkazao zahtev za stavke na Web lokaciji',
    'a_user_requested' => 'Korisnik je zatražio stavke na Web lokaciji',
    'accessory_name' => 'Naziv dodatne opreme, pribora:',
    'additional_notes' => 'Dodatne napomene:',
    'admin_has_created' => 'Administrator je kreirao nalog za vas na na :web vebsajtu.',
    'asset' => 'Imovina:',
    'asset_name' => 'Naziv imovine:',
    'asset_requested' => 'Traženo sredstvo',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Dodijeljena',
    'best_regards' => 'Srdačan pozdrav',
    'canceled' => 'Otkazano:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'click_to_confirm' => 'Kliknite na sljedeći link kako biste potvrdili svoj :web nalog:',
    'click_on_the_link_accessory' => 'Kliknite na link pri dnu da biste potvrdili da ste primili dodatnu opremu.',
    'click_on_the_link_asset' => 'Kliknite na link pri dnu da biste potvrdili da ste primili resurs, imovinu.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Trenutna QTY',
    'Days' => 'Dani',
    'days' => 'Dana',
    'expecting_checkin_date' => 'Expected Checkin Date:',
    'expires' => 'Ističe',
    'Expiring_Assets_Report' => 'Expiring Assets Report.',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report.',
    'hello' => 'Zdravo',
    'hi' => 'Zdravo',
    'i_have_read' => 'Pročitao sam i prihvatam uvete korištenja i primio sam ovu stavku.',
    'item' => 'Artikal:',
    'Item_Request_Canceled' => 'Zahtev za stavku je otkazan',
    'Item_Requested' => 'Zahtevana stavka',
    'link_to_update_password' => 'Kliknite na sljedeći link kako biste potvrdili svoj :web nalog:',
    'login_first_admin' => 'Login to your new Snipe-IT installation using the credentials below:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Izveštaj o niskim zalihama',
    'min_QTY' => 'Min Kol',
    'name' => 'Naziv',
    'new_item_checked' => 'Nova stavka je proverena pod vašim imenom, detalji su u nastavku.',
    'password' => 'Lozinka:',
    'password_reset' => 'Ponovno postavljanje lozinke',

    'read_the_terms' => 'Pročitajte uslove upotrebe u nastavku.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read
                         and agree to the terms of use, and have received the asset.',
    'requested' => 'Traženi:',
    'reset_link' => 'Link za resetovanje lozinke',
    'reset_password' => 'Kliknite ovde da biste poništili lozinku:',
    'serial' => 'Serial',
    'supplier' => 'Dobavljač',
    'tag' => 'Tag',
    'test_email' => 'Isprobajte e-poštu od Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'low_inventory_alert' => 'Postoji :count artikla ispod minimalne zalihe ili će uskoro biti nizak. |Postoje :count artikla koji su ispod minimalne zalihe ili će uskoro biti.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Postoji :count licenci koja/e ističe u narednih treshold dana.|Postoje :count licencei koje ističu u narednih :treshold dana.',
    'to_reset' => 'Da biste resetovali svoju :web lozinku, ispunite ovaj obrazac:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Korisnik',
    'username' => 'Korisničko ime',
    'welcome' => 'Dobrodošli :name',
    'welcome_to' => 'Dobrodošli na :web!',
    'your_credentials' => 'Vaši Snipe-IT kredencijali',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
